@@ -38,6 +38,7 @@ class TextVector:
 
         # -- transformers
         text = text.strip()
+        text = self.transform_special_characters(text)
         text = self.transform_hashtags(text)
         text = self.transform_latex(conf, text)
 
@@ -51,6 +52,36 @@ class TextVector:
 
         return stems
 
+    #
+    # SPECIAL CHARACTERS
+    #
+    def transform_special_characters(self, text):
+        weird = [
+            'ą', 'Ą', 'a\\u0328', 'A\\u0328',
+            'ę', 'Ę', 'e\\u0328', 'E\\u0328',
+            'ó', 'Ó', 'o\\u0301', 'O\\u0301',
+            'ć', 'Ć', 'c\\u0301', 'C\\u0301',
+            'ś', 'Ś', 's\\u0301', 'S\\u0301',
+            'ż', 'Ż', 'z\\u0307', 'Z\\u0307',
+            'ź', 'Ź', 'z\\u0301', 'Z\\u0301',
+            'ń', 'Ń', 'n\\u0301', 'N\\u0301',
+        ]
+        normal = [
+            'ą', 'Ą', '\u0105', '\u0104',
+            'ę', 'Ę', '\u0119', '\u0118',
+            'ó', 'Ó', '\xf3', '\xd3',
+            'ć', 'Ć', '\u0107', '\u0106',
+            'ś', 'Ś', '\u015b', '\u015a',
+            'ż', 'Ż', '\u017c', '\u017b',
+            'ź', 'Ź', '\u017a', '\u0179',
+            'ń', 'Ń', '\u0144', '\u0143',
+        ]
+
+        for w, n in zip(weird, normal):
+            text = text.replace(w, n)
+
+        return text
+
     #
     # HASHTAGS
     #
